@@ -131,7 +131,6 @@ else:
 
 # The following are columns that we add dynamically and internally, so we need
 # to make sure they have unique names that won't clash with existing columns
-SIZE_COLUMN_NAME = str(uuid.uuid4())
 CMAP_COLUMN_NAME = str(uuid.uuid4())
 TIME_COLUMN_NAME = str(uuid.uuid4())
 
@@ -238,6 +237,7 @@ class LayerManager(object):
     def __init__(self, parent=None):
         self._layers = []
         self._parent = parent
+        self._tmpdir = None
 
     def add_image_layer(
         self,
@@ -302,56 +302,12 @@ class LayerManager(object):
         # has previously been processed. As usual, the logic is a bit
         # complicated since we aim to allow the user to give us just about
         # anything as an input.
-
-        if isinstance(image, astropy.io.fits.HDUList):
-            if hdu_index:
-                image = image[hdu_index]  # delegate to the next stanza
-            else:
-                # NOTE: this is repeating `utils.sanitize_image()`. We do *not*
-                # delegate to the next stanza in case Toasty can do something
-                # with the full HDU list that is better than just picking one
-                # HDU -- so we must write out the full HDUList to disk, not just
-                # the first/best image HDU. That being said, we try to make it
-                # so that the cache key for `HDUList([hdu])` is the same as the
-                # cache key for `hdu`.
-                from hashlib import md5
-
-                m = md5()
-
-                for hdu in image:
-                    if (
-                        hasattr(hdu, "shape")
-                        and len(hdu.shape) > 1
-                        and not isinstance(hdu, astropy.io.fits.BinTableHDU)
-                    ):
-                        # We could `break` here, but it seems safer not to? And
-                        # the performance impact should be minimal.
-                        m.update(hdu.data[:65536])
-                        m.update(hdu.header.tostring().encode("utf-8"))
-
-                hex_string = m.hexdigest()
-                filename = "toasty_input_{}.fits".format(hex_string)
-
-                if not Path(filename).is_file():
-                    image.writeto(filename)
-
-                image = filename
-
-        if isinstance(image, astropy.io.fits.ImageHDU) or isinstance(
-            image, astropy.io.fits.PrimaryHDU
-        ):
-            from hashlib import md5
-
-            m = md5()
-            m.update(image.data[:65536])
-            m.update(image.header.tostring().encode("utf-8"))
-            hex_string = m.hexdigest()
-            filename = "toasty_input_{}.fits".format(hex_string)
-
-            if not Path(filename).is_file():
-                image.writeto(filename)
-
-            image = filename
+        if any(isinstance(image, fitsy_type) for fitsy_type in [
+            astropy.io.fits.HDUList,
+            astropy.io.fits.ImageHDU,
+            astropy.io.fits.PrimaryHDU
+        ]):
+            image = self._write_image_for_toasty(image, hdu_index=hdu_index)
 
         if isinstance(image, str):
             image = [image]
@@ -381,6 +337,66 @@ class LayerManager(object):
                 image=image[0], hdu_index=hdu_index, name=name, **kwargs
             )
 
+    def _write_image_for_toasty(self, image, hdu_index=None):
+        filename = self._toasty_filename(image, hdu_index=hdu_index)
+
+        try:
+            # If the magic filename already exists, assume that we've already
+            # written out the image, and save time by not rewriting this.
+            # Ideally we'd write out the image to a temporary path and rename
+            # atomically to avoid the risk of trying to read an image that some
+            # other process has only half-written.
+            if not Path(filename).is_file():
+                image.writeto(filename)
+            return filename
+        except OSError:
+            if self._tmpdir is None:
+                self._tmpdir = tempfile.TemporaryDirectory()
+            filepath = path.join(self._tmpdir.name, filename)
+
+            if not Path(filepath).is_file():
+                image.writeto(filepath)
+            return filepath
+
+    def _toasty_filename(self, image, hdu_index=None):
+        m = self._image_md5(image, hdu_index=hdu_index)
+        hex_string = m.hexdigest()
+        return "toasty_input_{}.fits".format(hex_string)
+
+    def _image_md5(self, image, hdu_index=None):
+        from hashlib import md5
+
+        m = md5()
+        if isinstance(image, astropy.io.fits.HDUList):
+            if hdu_index:
+                image = image[hdu_index]  # delegate to the next stanza
+            else:
+                # NOTE: this is repeating `utils.sanitize_image()`. We do *not*
+                # delegate to the next stanza in case Toasty can do something
+                # with the full HDU list that is better than just picking one
+                # HDU -- so we must write out the full HDUList to disk, not just
+                # the first/best image HDU. That being said, we try to make it
+                # so that the cache key for `HDUList([hdu])` is the same as the
+                # cache key for `hdu`.
+
+                for hdu in image:
+                    if (
+                        hasattr(hdu, "shape")
+                        and len(hdu.shape) > 1
+                        and not isinstance(hdu, astropy.io.fits.BinTableHDU)
+                    ):
+                        # We could `break` here, but it seems safer not to? And
+                        # the performance impact should be minimal.
+                        m.update(hdu.data[:65536])
+                        m.update(hdu.header.tostring().encode("utf-8"))
+
+        if isinstance(image, astropy.io.fits.ImageHDU) or isinstance(
+            image, astropy.io.fits.PrimaryHDU
+        ):
+            m.update(image.data[:65536])
+            m.update(image.header.tostring().encode("utf-8"))
+        return m
+
     def _create_and_add_image_layer(self, image, **kwargs):
         kwargs = self._remove_toasty_keywords(**kwargs)
         layer = self._parent._create_image_layer(image=image, **kwargs)
@@ -1371,16 +1387,29 @@ class TableLayer(HasTraits):
                 state["settings"][wwt_name] = value
 
         if self._uniform_color():
-            state["settings"]["_colorMap"] = 0
+            state["settings"]["colorMap"] = 0
             state["settings"]["colorMapColumn"] = -1
+        elif self.cmap.name.lower() in VALID_COLORMAPS:
+            state["settings"]["colorMap"] = 3
+            state["settings"]["colorMapperName"] = self.cmap.name
+            state["settings"]["dynamicColor"] = True
+            state["settings"]["normalizeColorMap"] = True
+            state["settings"]["normalizeColorMapMin"] = self.cmap_vmin
+            state["settings"]["normalizeColorMapMax"] = self.cmap_vmax
+            state["settings"]["colorMapColumn"] = self.cmap_att
         else:
-            state["settings"]["_colorMap"] = 3
+            state["settings"]["colorMap"] = 3
             state["settings"]["colorMapColumn"] = CMAP_COLUMN_NAME
+            state["settings"]["dynamicColor"] = False
 
         if self._uniform_size():
             state["settings"]["sizeColumn"] = -1
         else:
-            state["settings"]["sizeColumn"] = SIZE_COLUMN_NAME
+            state["settings"]["sizeColumn"] = self.size_att
+            state["settings"]["normalizeSize"] = True
+            state["settings"]["normalizeSizeMin"] = self.size_vmin
+            state["settings"]["normalizeSizeMax"] = self.size_vmax
+            state["settings"]["normalizeSizeClip"] = True
             state["settings"]["pointScaleType"] = 0
 
         return state
