@@ -636,7 +636,7 @@ def _translate_glob(pat):
         translated_parts.append(_translate_glob_part(part))
     os_sep_class = "[%s]" % re.escape(SEPARATORS)
     res = _join_translated(translated_parts, os_sep_class)
-    return "{res}\\Z(?ms)".format(res=res)
+    return f"(?ms){res}\\Z"
 
 
 def _join_translated(translated_parts, os_sep_class):
